import { Track } from 'livekit-client';
import { useEffect, useState } from 'react';
import { addListener, removeListener } from '../events/EventEmitter';
import LiveKitModule from '../LKNativeModule';

/**
 * A hook for tracking the volume of an audio track.
 *
 * @param trackOrTrackReference
 * @returns A number between 0-1 representing the volume.
 */
export function useTrackVolume(trackOrTrackReference) {
  var _trackOrTrackReferenc;
  const track = trackOrTrackReference instanceof Track ? trackOrTrackReference : trackOrTrackReference === null || trackOrTrackReference === void 0 || (_trackOrTrackReferenc = trackOrTrackReference.publication) === null || _trackOrTrackReferenc === void 0 ? void 0 : _trackOrTrackReferenc.track;
  const mediaStreamTrack = track === null || track === void 0 ? void 0 : track.mediaStreamTrack;
  let [volume, setVolume] = useState(0.0);
  useEffect(() => {
    let listener = Object();
    let reactTag = null;
    if (mediaStreamTrack) {
      reactTag = LiveKitModule.createVolumeProcessor(mediaStreamTrack._peerConnectionId ?? -1, mediaStreamTrack.id);
      addListener(listener, 'LK_VOLUME_PROCESSED', event => {
        if (event.volume && reactTag && event.id === reactTag) {
          setVolume(event.volume);
        }
      });
    }
    return () => {
      if (mediaStreamTrack) {
        removeListener(listener);
        if (reactTag) {
          LiveKitModule.deleteVolumeProcessor(reactTag, mediaStreamTrack._peerConnectionId ?? -1, mediaStreamTrack.id);
        }
      }
    };
  }, [mediaStreamTrack]);
  return volume;
}
//# sourceMappingURL=useTrackVolume.js.map